# Installing
```
python3 -m pip install aiocloud
```
### Disclaimer
This library is *very* incomplete and created for a single project!  
That being said, I will probably get to finish it sometime soon <3
